@@ -1,18 +1,14 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 #include <kernelmessageswindow.h>
+#include <helpwindow.h>
 #include <QMainWindow>
-#include <QMessageBox>
-#include <unistd.h>
-#include <QProcess>
-#include <iostream>
-#include <unistd.h>
-#include <string>
-#include <stdio.h>
-#include <aboutdialog.h>
+#include <aboutwindow.h>
 #include <QDebug>
 #include <QIODevice>
 #include <QFile>
+#include <QtGui>
+#include <stdlib.h>
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
 #endif
@@ -28,7 +24,7 @@ class MainWindow : public QMainWindow
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
-    QString *line;
+    QString *kernelversion;
 
 private:
     Ui::MainWindow *ui;
@@ -37,11 +33,16 @@ private:
 
 private slots:
     void about();
-    void hostmodeVBUSAction();
-    void hostmode();
+    void hostmodeFS();
+    void hostmodeLS();
+    void hostmodeHS();
     void mountdevsda1();
-    void startbme();
+    void vbusOn();
+    void vbusOff();
     void kernelmessages();
+    void orientationChanged();
+    void enumerate();
+    void helpWindow();
 };
 
 #endif // MAINWINDOW_H
